@@ -28,12 +28,21 @@ class loadClassifierDataset(data.Dataset):
                 task_dict = outdata['task']
         else:
             task_dict = {}
+            total_data = 0
+            data_exceed_maxlen = 0
             for i in tqdm(get_data_from_file(fpath)):
                 all_task, task, input, target = i
                 task_dict.update(all_task)
                 feature = get_feature_from_data(tokenizer, maxlen, all_task, task, input, target)
                 if len(feature['input']) <= maxlen:
                     sample.append(feature)
+                else:
+                    data_exceed_maxlen += 1
+                total_data += 1
+
+            print("Processed " + str(total_data) + " data, removed " + str(
+                data_exceed_maxlen) + " data that exceed the maximum length.")
+
             if cache:
                 with open(cache_path, 'wb') as cf:
                     outdata = {'sample': sample, 'task': task_dict}
@@ -59,12 +68,18 @@ def get_data_from_file(fpath):
     with open(fpath, 'r', encoding='utf8', newline='') as csvfile:
         reader = csv.reader(csvfile)
         reader = list(reader)
-        headers = ['input'] + ['target_' + str(i) for i in range(len(reader[0])-1)]
+        headers = ['input'] + ['target_' + str(i) for i in range(len(reader[0]) - 1)]
+        is_multi_label = ""
+        for row in reader:
+            if '/' in row[1]:
+                is_multi_label = "_multi_label"
+                break
+
         for row in reader:
             start_pos = 1
             for pos, item in enumerate(row[start_pos:]):
                 pos += start_pos
-                task = headers[0] + "_" + headers[pos]
+                task = headers[0] + "_" + headers[pos] + is_multi_label
                 item = item.strip()
                 if '/' in item:
                     for i in item.split("/"):
@@ -77,7 +92,7 @@ def get_data_from_file(fpath):
             start_pos = 1
             for pos, item in enumerate(row[start_pos:]):
                 pos += start_pos
-                task = headers[0] + "_" + headers[pos]
+                task = headers[0] + "_" + headers[pos] + is_multi_label
                 item = item.strip()
                 target = item.split('/') if '/' in item else [item]
                 input = row[0]
@@ -102,9 +117,9 @@ def get_feature_from_data(tokenizer, maxlen, task_lables, task, input, target=No
     row_dict['mask'] = mask_id
     row_dict['target'] = [-1]
     if target is not None:
-        if 'multi_target' in task:
-            mlb = MultiLabelBinarizer(classes=task_lables)
-            tar = mlb.fit_transform([target.split("/")])
+        if 'multi_label' in task:
+            mlb = MultiLabelBinarizer(classes=task_lables[task])
+            tar = mlb.fit_transform([target])
             tokenize_label = tar
         else:
             tokenize_label = [task_lables[task].index(target[0])]
